"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prompts_1 = __importDefault(require("prompts"));
/**
 * The `prompts` library doesn't always interpret CTRL+C and release the terminal back to the user
 * so we need handle this ourselves. This function is just a simple overload of the main `prompts`
 * import that we use.
 *
 * @see {@link https://github.com/terkelg/prompts/issues/252}
 */
async function promptTerminal(question, options) {
    const enableTerminalCursor = () => {
        process.stdout.write('\x1B[?25h');
    };
    const onState = (state) => {
        if (state.aborted) {
            // If we don't re-enable the terminal cursor before exiting the program, the cursor will
            // remain hidden.
            enableTerminalCursor();
            process.stdout.write('\n');
            process.exit(1);
        }
    };
    return (0, prompts_1.default)({ ...question, onState }, options);
}
exports.default = promptTerminal;
